@@ -6,6 +6,7 @@ from unittest import mock
 import pytest
 
 from faker import Faker, providers
+from faker.providers.address.az_AZ import Provider as AzAzAddressProvider
 from faker.providers.address.cs_CZ import Provider as CsCzAddressProvider
 from faker.providers.address.da_DK import Provider as DaDkAddressProvider
 from faker.providers.address.de_AT import Provider as DeAtAddressProvider
@@ -111,6 +112,47 @@ class TestBaseProvider:
             Faker("en_US").current_country()
 
 
+class TestAzAz:
+    """Test az_AZ address provider methods"""
+
+    def test_street_suffix_long(self, faker, num_samples):
+        for _ in range(num_samples):
+            street_suffix_long = faker.street_suffix()
+            assert isinstance(street_suffix_long, str)
+            assert street_suffix_long in AzAzAddressProvider.street_suffixes
+
+    def test_city_name(self, faker, num_samples):
+        for _ in range(num_samples):
+            city = faker.city()
+            assert isinstance(city, str)
+            assert city in AzAzAddressProvider.cities
+
+    def test_street_name(self, faker, num_samples):
+        for _ in range(num_samples):
+            street_name = faker.street()
+            assert isinstance(street_name, str)
+            assert street_name in AzAzAddressProvider.streets
+
+    def test_settlement_name(self, faker, num_samples):
+        for _ in range(num_samples):
+            settlement_name = faker.settlement()
+            assert isinstance(settlement_name, str)
+            assert settlement_name in AzAzAddressProvider.settlements
+
+    def test_village_name(self, faker, num_samples):
+        for _ in range(num_samples):
+            village_name = faker.village()
+            assert isinstance(village_name, str)
+            assert village_name in AzAzAddressProvider.villages
+
+    def test_postcode(self, faker, num_samples):
+        for _ in range(num_samples):
+            postcode = faker.postcode()
+            assert isinstance(postcode, str)
+            assert re.fullmatch(r"AZ\d{4}", postcode)
+            assert int(postcode[2:]) in range(900, 6600)
+
+
 class TestCsCz:
     """Test cs_CZ address provider methods"""
 
